@@ -3,6 +3,7 @@
 ;; Copyright (C) 1998, 1999 Free Software Foundation, Inc.
 ;; Copyright (C) 2001, 2002, 2003, 2004 Peter S Galbraith <psg@debian.org>
 ;; Copyright (C) 2005, 2006, 2007, 2008 Peter S Galbraith <psg@debian.org>
+;; Copyright (C) 2009 Peter S Galbraith <psg@debian.org>
 
 ;; Help texts from
 ;;  http://www.debian.org/Bugs/Developer#severities
@@ -11,7 +12,7 @@
 ;; Copyright 1999 Darren O. Benham, 1994-1997 Ian Jackson,
 ;;  1997 nCipher Corporation Ltd.
 
-;; Author (Up to version 1.7):           Francesco Potort <pot@gnu.org>
+;; Author (Up to version 1.7):           Francesco Potortì <pot@gnu.org>
 ;; Maintainer from version 1.8 onwards:  Peter S Galbraith <psg@debian.org>
 ;; Keywords: debian, bug, reporter
 
@@ -43,9 +44,9 @@
 ;; ----------------------------------------------------------------------------
 ;;; Change log:
 ;;
-;; V1.5 23sep99 Francesco Potort <pot@gnu.org>
+;; V1.5 23sep99 Francesco Potortì <pot@gnu.org>
 ;;  - V1.1 -> 1.5 versions had no changelogs; starting one now.
-;; V1.5 and V1.7 by Francesco Potort <pot@gnu.org> were unreleased.
+;; V1.5 and V1.7 by Francesco Potortì <pot@gnu.org> were unreleased.
 ;; V1.8 04aug01 Peter S Galbraith <psg@debian.org>
 ;;  - WNPP interface code added.  I'm unsure whether the functions useful
 ;;    only to Debian developpers should be in here.  Perhaps split into a
@@ -292,6 +293,16 @@
 ;; V1.67 09Sept2008 Peter S Galbraith <psg@debian.org>
 ;;  - Bug fix: "Bug submenus have vanished", thanks to Bill Wohler for the
 ;;    report and to Camm Maguire for an initial patch (Closes: #463053).
+;; V1.68 23Feb2009 Peter S Galbraith <psg@debian.org>
+;;  - Bug fix: Adapted patch from Håkon Stordahl <haastord@online.no> to
+;;    quote bug descriptions when building the bug menu. (Closes: #489786)
+;;  - Bug fix: Applied patch from Håkon Stordahl <hakon@stordahl.org>
+;;    for garbled Help buffer (Closes: #502426)
+;; V1.69 13May2009 Peter S Galbraith <psg@debian.org>
+;;  - Updated debian-bug-pseudo-packages (Closes: #526496)
+;;  - [PATCH] using the "maintainer mbox" instead of "mbox folder".
+;;    Thanks to Evgeny M. Zubok (Closes: #521571).
+;;  - Fix "incomplete Bugs menu again", thanks to A Mennucc (Closes: #524043).
 ;; ----------------------------------------------------------------------------
 
 ;;; Todo (Peter's list):
@@ -498,12 +509,12 @@ Debian maintainers.")
   "Alist of all valid Tags, aimed at Debian developpers.")
 
 (defvar debian-bug-pseudo-packages
-  '("base" "bugs.debian.org" "cdimage.debian.org" "cdrom"
-    "ftp.debian.org" "general"
-    "installation-reports" "kernel" "listarchives"
-    "lists.debian.org" "mirrors" "press"
-    "project" "qa.debian.org" "release-notes" "security.debian.org" "tech-ctte"
-    "upgrade-reports" "wnpp" "www.debian.org")
+  '("base" "bugs.debian.org" "buildd.debian.org" "buildd.emdebian.org"
+    "cdimage.debian.org" "cdrom" "debian-i18n" "ftp.debian.org" "general"
+    "installation-reports" "lists.debian.org" "mirrors" "nm.debian.org"
+    "press" "project" "qa.debian.org" "release-notes" "release.debian.org"
+    "security-tracker" "security.debian.org" "tech-ctte" "upgrade-reports"
+    "wiki.debian.org" "wnpp" "www.debian.org")
   "List of Debian pseudo-packages available for completion.
 See http://www.debian.org/Bugs/pseudo-packages")
 
@@ -1246,34 +1257,36 @@ Sep 22, 2006")))
   (with-output-to-temp-buffer "*Help*"
     (princ "List of Debian pseudo packages
 
- base -- Base system (baseX_Y.tgz) general bugs
- boot-floppy -- Installation system
- bugs.debian.org -- The bug tracking system, @bugs.debian.org
- cdimage.debian.org -- CD Image issues
- cdrom -- Installation system
- ftp.debian.org -- Problems with the FTP site
- general -- General problems (e.g. \"many manpages are mode 755\")
- install -- Installation system
- installation -- Installation system
- installation-reports -- Reports of installation problems with stable & testing
- kernel -- Problems with the Linux kernel, or that shipped with Debian
- listarchives -- Problems with the WWW mailing list archives
- lists.debian.org -- The mailing lists, debian-*@lists.debian.org
- mirrors -- Problems with the official mirrors
- nonus.debian.org -- Problems with the non-US FTP site
- potato-cd -- Potato CD
- press -- Press release issues
- project -- Problems related to project administration
- qa.debian.org -- The Quality Assurance group
- security.debian.org -- The Debian Security Team
- tech-ctte -- The Debian Technical Committee (see the Constitution)
- upgrade-reports -- Reports of upgrade problems for stable & testing
- wnpp -- Work-Needing and Prospective Packages list
- www.debian.org -- Problems with the WWW site
+ base — Base system general bugs
+ bugs.debian.org — The bug tracking system, @bugs.debian.org
+ buildd.debian.org — Problems and requests related to the Debian Buildds
+ buildd.emdebian.org — Problems related to building packages for Emdebian
+ cdimage.debian.org — CD Image issues
+ cdrom — Installation system
+ debian-i18n — Requests regarding Internationalization (i18n) of the distribution
+ ftp.debian.org — Problems with the FTP site
+ general — General problems (e.g. \"many manpages are mode 755\")
+ installation-reports — Reports of installation problems with stable & testing
+ lists.debian.org — The mailing lists, debian-*@lists.debian.org
+ mirrors — Problems with the official mirrors
+ nm.debian.org — New Maintainer process and nm.debian.org webpages
+ press — Press release issues
+ project — Problems related to project administration
+ qa.debian.org — The Quality Assurance group
+ release-notes — Problems with the Release Notes
+ release.debian.org — Requests regarding Debian releases and release team tools
+ security-tracker — The Debian Security Bug Tracker
+ security.debian.org — The Debian Security Team
+ tech-ctte — The Debian Technical Committee (see the Constitution)
+ upgrade-reports — Reports of upgrade problems for stable & testing
+ wiki.debian.org — Problems with the Debian wiki
+ wnpp — Work-Needing and Prospective Packages list
+ www.debian.org — Problems with the WWW site 
 
-from http://www.debian.org/Bugs/pseudo-packages, Apr 22th 2003.
-Copyright 1999 Darren O. Benham, 1994-1997 Ian Jackson,
- 1997 nCipher Corporation Ltd.")))
+from http://www.debian.org/Bugs/pseudo-packages, May 12th 2009.
+Copyright 1999 Darren O. Benham, 1997, 2003 nCipher Corporation Ltd,
+1994-1997 Ian Jackson.
+")))
 
 (defun debian-bug-help-email ()
   "Display help about various bug report emails to use."
@@ -1689,7 +1702,7 @@ If SUBMENU is t, then check for current sexp submenu only."
                      debian-bug-download-directory))
           (status)
           (url (concat "http://bugs.debian.org/cgi-bin/bugreport.cgi?bug="
-                       bug-number "&mbox=yes")))
+                       bug-number "&mbox=yes&mboxmaint=yes")))
       (if (and (file-exists-p filename)
                (not (y-or-n-p "Bug file already exists.  Download again? ")))
           filename
@@ -1827,21 +1840,26 @@ Only decodes if `rfc2047-decode-string' is available."
 	(goto-char (point-min))
         (while
             (re-search-forward
-             "\\(<H2.*</a>\\(.+\\)</H2>\\)\\|\\(<a href=\"\\(bugreport.cgi\\?bug=\\([0-9]+\\)\\)\">\\(.+: \\(.+\\)\\)</a>\\)"
+;;;          "\\(<H2.*</a>\\(.+\\)</H2>\\)\\|\\(<a href=\"\\(bugreport.cgi\\?bug=\\([0-9]+\\)\\)\">\\(.+: \\(.+\\)\\)</a>\\)"
+             "\\(<H2.*</a>\\(.+\\)</H2>\\)\\|\\(<a href=\"\\(bugreport.cgi\\?bug=\\([0-9]+\\)\\)\">\\(.+\\)</a>\\)"
              nil t)
           (let ((type (match-string 2))
               ;;(URL (match-string 4))
                 (bugnumber (match-string 5))
                 (description (match-string 6))
-                (shortdescription (match-string 7)))
+                (shortdescription (match-string 6)))
             (cond
-             ((string= type "-->"))          ;Do nothing
+             ((string= type "-->"))                  ;Do nothing
              (type
               (setq bugs-are-open-flag (not (string-match "resolved" type)))
               (save-excursion
                 (set-buffer debian-bug-tmp-buffer)
                 (insert "\"-\"\n\"" type "\"\n")))
+             ((null description))                    ;Do nothing
+             ((string-match "^#?[0-9]+$" description)) ;Do nothing
              (t
+              (if (string-match "^[^ ]+: \\(.+\\)" description)
+                  (setq shortdescription (match-string 1 description)))
               (setq bug-alist (cons (list bugnumber description) bug-alist))
               (when bugs-are-open-flag
                 (when (and (re-search-forward
@@ -1866,11 +1884,12 @@ Only decodes if `rfc2047-decode-string' is available."
               (save-excursion
                 (set-buffer debian-bug-tmp-buffer)
                 (insert
-                 "[\"#"  bugnumber " "
-                 (if (< 60 (length description))
-                     (substring description 0 60)
-                   description)
-                 "\" (debian-bug-menu-action \"" bugnumber "\")"
+                 "["
+                 (format "%S" (concat "#" bugnumber " "
+                                      (if (< 60 (length description))
+                                          (substring description 0 60)
+                                        description)))
+                 " (debian-bug-menu-action \"" bugnumber "\")"
                  " :active "
                  (if bugs-are-open-flag
                      "t"
@@ -1986,6 +2005,7 @@ Call this function from the mode setup with MINOR-MODE-MAP."
             (if package
                 package
               (message "Calling dpkg for the search...")
+              (erase-buffer)
               (call-process "dpkg" nil '(t nil) nil "-S"
                             (expand-file-name filename))
               (message "Calling dpkg for the search...done")
