@@ -405,6 +405,26 @@ effect.  Therefore it is recommended to `newsticker-stop' and then
 ;;:require 'protbuf
   :group 'emacs-goodies-el)
 
+;; quack
+(defgroup quack nil
+  "Enhanced support for editing and running Scheme code."
+  :group  'scheme
+  :prefix "quack-"
+  :link   '(url-link "http://www.neilvandyke.org/quack/")
+  :load 'quack
+  :link '(custom-manual "(emacs-goodies-el)quack")
+  :group 'emacs-goodies-el)
+
+(defcustom quack-install nil
+  "Whether to setup quack for use."
+  :type 'boolean
+  :set (lambda (symbol value)
+         (set-default symbol value)
+         (when value
+           (quack-install)))
+  :require 'quack
+  :group 'quack)
+
 ;; rfcview
 (defgroup rfcview nil
   "View IETF RFC files with formatting."
